==> knative-model-6.8.1-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/IngressStatusFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IngressStatusFluent<A extends IngressStatusFluent<A>> extends BaseFluent<A>{
  public IngressStatusFluent() {
  }
  public IngressStatusFluent(IngressStatus instance) {
    instance = (instance != null ? instance : new IngressStatus());

    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withPrivateLoadBalancer(instance.getPrivateLoadBalancer());
      this.withPublicLoadBalancer(instance.getPublicLoadBalancer());
      this.withAnnotations(instance.getAnnotations());
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withPrivateLoadBalancer(instance.getPrivateLoadBalancer());
      this.withPublicLoadBalancer(instance.getPublicLoadBalancer());
    }
  }
  private Map<String,String> annotations;
  private ArrayList<ConditionBuilder> conditions = new ArrayList<ConditionBuilder>();
  private Long observedGeneration;
  private LoadBalancerStatusBuilder privateLoadBalancer;
  private LoadBalancerStatusBuilder publicLoadBalancer;
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  public A addToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    ConditionBuilder builder = new ConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  public A setToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    ConditionBuilder builder = new ConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(Collection<Condition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items) {
    if (this.conditions == null) return (A)this;
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  public A removeAllFromConditions(Collection<Condition> items) {
    if (this.conditions == null) return (A)this;
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<ConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      ConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<Condition> buildConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public Condition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  public Condition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public Condition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate) {
    for (ConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate) {
    for (ConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<Condition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").clear();}
    if (conditions != null) {this.conditions = new ArrayList(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear(); _visitables.remove("conditions"); }
    if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  public ConditionsNested<A> addNewConditionLike(Condition item) {
    return new ConditionsNested(-1, item);
  }
  public ConditionsNested<A> setNewConditionLike(int index,Condition item) {
    return new ConditionsNested(index, item);
  }
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public Long getObservedGeneration() {
    return this.observedGeneration;
  }
  public A withObservedGeneration(Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  public boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  public LoadBalancerStatus buildPrivateLoadBalancer() {
    return this.privateLoadBalancer!=null ?this.privateLoadBalancer.build():null;
  }
  public A withPrivateLoadBalancer(LoadBalancerStatus privateLoadBalancer) {
    _visitables.get("privateLoadBalancer").remove(this.privateLoadBalancer);
    if (privateLoadBalancer!=null){ this.privateLoadBalancer= new LoadBalancerStatusBuilder(privateLoadBalancer); _visitables.get("privateLoadBalancer").add(this.privateLoadBalancer);} else { this.privateLoadBalancer = null; _visitables.get("privateLoadBalancer").remove(this.privateLoadBalancer); } return (A) this;
  }
  public boolean hasPrivateLoadBalancer() {
    return this.privateLoadBalancer != null;
  }
  public PrivateLoadBalancerNested<A> withNewPrivateLoadBalancer() {
    return new PrivateLoadBalancerNested(null);
  }
  public PrivateLoadBalancerNested<A> withNewPrivateLoadBalancerLike(LoadBalancerStatus item) {
    return new PrivateLoadBalancerNested(item);
  }
  public PrivateLoadBalancerNested<A> editPrivateLoadBalancer() {
    return withNewPrivateLoadBalancerLike(java.util.Optional.ofNullable(buildPrivateLoadBalancer()).orElse(null));
  }
  public PrivateLoadBalancerNested<A> editOrNewPrivateLoadBalancer() {
    return withNewPrivateLoadBalancerLike(java.util.Optional.ofNullable(buildPrivateLoadBalancer()).orElse(new LoadBalancerStatusBuilder().build()));
  }
  public PrivateLoadBalancerNested<A> editOrNewPrivateLoadBalancerLike(LoadBalancerStatus item) {
    return withNewPrivateLoadBalancerLike(java.util.Optional.ofNullable(buildPrivateLoadBalancer()).orElse(item));
  }
  public LoadBalancerStatus buildPublicLoadBalancer() {
    return this.publicLoadBalancer!=null ?this.publicLoadBalancer.build():null;
  }
  public A withPublicLoadBalancer(LoadBalancerStatus publicLoadBalancer) {
    _visitables.get("publicLoadBalancer").remove(this.publicLoadBalancer);
    if (publicLoadBalancer!=null){ this.publicLoadBalancer= new LoadBalancerStatusBuilder(publicLoadBalancer); _visitables.get("publicLoadBalancer").add(this.publicLoadBalancer);} else { this.publicLoadBalancer = null; _visitables.get("publicLoadBalancer").remove(this.publicLoadBalancer); } return (A) this;
  }
  public boolean hasPublicLoadBalancer() {
    return this.publicLoadBalancer != null;
  }
  public PublicLoadBalancerNested<A> withNewPublicLoadBalancer() {
    return new PublicLoadBalancerNested(null);
  }
  public PublicLoadBalancerNested<A> withNewPublicLoadBalancerLike(LoadBalancerStatus item) {
    return new PublicLoadBalancerNested(item);
  }
  public PublicLoadBalancerNested<A> editPublicLoadBalancer() {
    return withNewPublicLoadBalancerLike(java.util.Optional.ofNullable(buildPublicLoadBalancer()).orElse(null));
  }
  public PublicLoadBalancerNested<A> editOrNewPublicLoadBalancer() {
    return withNewPublicLoadBalancerLike(java.util.Optional.ofNullable(buildPublicLoadBalancer()).orElse(new LoadBalancerStatusBuilder().build()));
  }
  public PublicLoadBalancerNested<A> editOrNewPublicLoadBalancerLike(LoadBalancerStatus item) {
    return withNewPublicLoadBalancerLike(java.util.Optional.ofNullable(buildPublicLoadBalancer()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressStatusFluent that = (IngressStatusFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;

    if (!java.util.Objects.equals(conditions, that.conditions)) return false;

    if (!java.util.Objects.equals(observedGeneration, that.observedGeneration)) return false;

    if (!java.util.Objects.equals(privateLoadBalancer, that.privateLoadBalancer)) return false;

    if (!java.util.Objects.equals(publicLoadBalancer, that.publicLoadBalancer)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  conditions,  observedGeneration,  privateLoadBalancer,  publicLoadBalancer,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (observedGeneration != null) { sb.append("observedGeneration:"); sb.append(observedGeneration + ","); }
    if (privateLoadBalancer != null) { sb.append("privateLoadBalancer:"); sb.append(privateLoadBalancer + ","); }
    if (publicLoadBalancer != null) { sb.append("publicLoadBalancer:"); sb.append(publicLoadBalancer); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends ConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,Condition item) {
      this.index = index;
      this.builder = new ConditionBuilder(this, item);
    }
    ConditionBuilder builder;
    int index;
    public N and() {
      return (N) IngressStatusFluent.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  public class PrivateLoadBalancerNested<N> extends LoadBalancerStatusFluent<PrivateLoadBalancerNested<N>> implements Nested<N>{
    PrivateLoadBalancerNested(LoadBalancerStatus item) {
      this.builder = new LoadBalancerStatusBuilder(this, item);
    }
    LoadBalancerStatusBuilder builder;
    public N and() {
      return (N) IngressStatusFluent.this.withPrivateLoadBalancer(builder.build());
    }
    public N endPrivateLoadBalancer() {
      return and();
    }
    
  }
  public class PublicLoadBalancerNested<N> extends LoadBalancerStatusFluent<PublicLoadBalancerNested<N>> implements Nested<N>{
    PublicLoadBalancerNested(LoadBalancerStatus item) {
      this.builder = new LoadBalancerStatusBuilder(this, item);
    }
    LoadBalancerStatusBuilder builder;
    public N and() {
      return (N) IngressStatusFluent.this.withPublicLoadBalancer(builder.build());
    }
    public N endPublicLoadBalancer() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/networking/v1alpha1/IngressStatusFluent.java <==
package io.fabric8.knative.internal.networking.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class IngressStatusFluent<A extends IngressStatusFluent<A>> extends BaseFluent<A>{
  public IngressStatusFluent() {
  }
  
  public IngressStatusFluent(IngressStatus instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> annotations;
  private ArrayList<ConditionBuilder> conditions = new ArrayList<ConditionBuilder>();
  private Long observedGeneration;
  private LoadBalancerStatusBuilder privateLoadBalancer;
  private LoadBalancerStatusBuilder publicLoadBalancer;
  
  protected void copyInstance(IngressStatus instance) {
    instance = (instance != null ? instance : new IngressStatus());
  
    if (instance != null) {
        this.withAnnotations(instance.getAnnotations());
        this.withConditions(instance.getConditions());
        this.withObservedGeneration(instance.getObservedGeneration());
        this.withPrivateLoadBalancer(instance.getPrivateLoadBalancer());
        this.withPublicLoadBalancer(instance.getPublicLoadBalancer());
        this.withAnnotations(instance.getAnnotations());
        this.withConditions(instance.getConditions());
        this.withObservedGeneration(instance.getObservedGeneration());
        this.withPrivateLoadBalancer(instance.getPrivateLoadBalancer());
        this.withPublicLoadBalancer(instance.getPublicLoadBalancer());
      }
  }
  
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  
  public A addToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    ConditionBuilder builder = new ConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  
  public A setToConditions(int index,Condition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    ConditionBuilder builder = new ConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A addAllToConditions(Collection<Condition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<ConditionBuilder>();}
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items) {
    if (this.conditions == null) return (A)this;
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConditions(Collection<Condition> items) {
    if (this.conditions == null) return (A)this;
    for (Condition item : items) {ConditionBuilder builder = new ConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<ConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      ConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<Condition> buildConditions() {
    return conditions != null ? build(conditions) : null;
  }
  
  public Condition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  
  public Condition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  
  public Condition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate) {
    for (ConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate) {
    for (ConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withConditions(List<Condition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").clear();}
    if (conditions != null) {this.conditions = new ArrayList(); for (Condition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions) {
    if (this.conditions != null) {this.conditions.clear(); _visitables.remove("conditions"); }
    if (conditions != null) {for (Condition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  
  public boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  
  public ConditionsNested<A> addNewConditionLike(Condition item) {
    return new ConditionsNested(-1, item);
  }
  
  public ConditionsNested<A> setNewConditionLike(int index,Condition item) {
    return new ConditionsNested(index, item);
  }
  
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public Long getObservedGeneration() {
    return this.observedGeneration;
  }
  
  public A withObservedGeneration(Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  
  public boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  
  public LoadBalancerStatus buildPrivateLoadBalancer() {
    return this.privateLoadBalancer!=null ?this.privateLoadBalancer.build():null;
  }
  
  public A withPrivateLoadBalancer(LoadBalancerStatus privateLoadBalancer) {
    _visitables.get("privateLoadBalancer").remove(this.privateLoadBalancer);
    if (privateLoadBalancer!=null){ this.privateLoadBalancer= new LoadBalancerStatusBuilder(privateLoadBalancer); _visitables.get("privateLoadBalancer").add(this.privateLoadBalancer);} else { this.privateLoadBalancer = null; _visitables.get("privateLoadBalancer").remove(this.privateLoadBalancer); } return (A) this;
  }
  
  public boolean hasPrivateLoadBalancer() {
    return this.privateLoadBalancer != null;
  }
  
  public PrivateLoadBalancerNested<A> withNewPrivateLoadBalancer() {
    return new PrivateLoadBalancerNested(null);
  }
  
  public PrivateLoadBalancerNested<A> withNewPrivateLoadBalancerLike(LoadBalancerStatus item) {
    return new PrivateLoadBalancerNested(item);
  }
  
  public PrivateLoadBalancerNested<A> editPrivateLoadBalancer() {
    return withNewPrivateLoadBalancerLike(java.util.Optional.ofNullable(buildPrivateLoadBalancer()).orElse(null));
  }
  
  public PrivateLoadBalancerNested<A> editOrNewPrivateLoadBalancer() {
    return withNewPrivateLoadBalancerLike(java.util.Optional.ofNullable(buildPrivateLoadBalancer()).orElse(new LoadBalancerStatusBuilder().build()));
  }
  
  public PrivateLoadBalancerNested<A> editOrNewPrivateLoadBalancerLike(LoadBalancerStatus item) {
    return withNewPrivateLoadBalancerLike(java.util.Optional.ofNullable(buildPrivateLoadBalancer()).orElse(item));
  }
  
  public LoadBalancerStatus buildPublicLoadBalancer() {
    return this.publicLoadBalancer!=null ?this.publicLoadBalancer.build():null;
  }
  
  public A withPublicLoadBalancer(LoadBalancerStatus publicLoadBalancer) {
    _visitables.get("publicLoadBalancer").remove(this.publicLoadBalancer);
    if (publicLoadBalancer!=null){ this.publicLoadBalancer= new LoadBalancerStatusBuilder(publicLoadBalancer); _visitables.get("publicLoadBalancer").add(this.publicLoadBalancer);} else { this.publicLoadBalancer = null; _visitables.get("publicLoadBalancer").remove(this.publicLoadBalancer); } return (A) this;
  }
  
  public boolean hasPublicLoadBalancer() {
    return this.publicLoadBalancer != null;
  }
  
  public PublicLoadBalancerNested<A> withNewPublicLoadBalancer() {
    return new PublicLoadBalancerNested(null);
  }
  
  public PublicLoadBalancerNested<A> withNewPublicLoadBalancerLike(LoadBalancerStatus item) {
    return new PublicLoadBalancerNested(item);
  }
  
  public PublicLoadBalancerNested<A> editPublicLoadBalancer() {
    return withNewPublicLoadBalancerLike(java.util.Optional.ofNullable(buildPublicLoadBalancer()).orElse(null));
  }
  
  public PublicLoadBalancerNested<A> editOrNewPublicLoadBalancer() {
    return withNewPublicLoadBalancerLike(java.util.Optional.ofNullable(buildPublicLoadBalancer()).orElse(new LoadBalancerStatusBuilder().build()));
  }
  
  public PublicLoadBalancerNested<A> editOrNewPublicLoadBalancerLike(LoadBalancerStatus item) {
    return withNewPublicLoadBalancerLike(java.util.Optional.ofNullable(buildPublicLoadBalancer()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressStatusFluent that = (IngressStatusFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;
  
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;
  
    if (!java.util.Objects.equals(observedGeneration, that.observedGeneration)) return false;
  
    if (!java.util.Objects.equals(privateLoadBalancer, that.privateLoadBalancer)) return false;
  
    if (!java.util.Objects.equals(publicLoadBalancer, that.publicLoadBalancer)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(annotations,  conditions,  observedGeneration,  privateLoadBalancer,  publicLoadBalancer,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (observedGeneration != null) { sb.append("observedGeneration:"); sb.append(observedGeneration + ","); }
    if (privateLoadBalancer != null) { sb.append("privateLoadBalancer:"); sb.append(privateLoadBalancer + ","); }
    if (publicLoadBalancer != null) { sb.append("publicLoadBalancer:"); sb.append(publicLoadBalancer); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends ConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,Condition item) {
      this.index = index;
      this.builder = new ConditionBuilder(this, item);
    }
    ConditionBuilder builder;
    int index;
    
    public N and() {
      return (N) IngressStatusFluent.this.setToConditions(index,builder.build());
    }
    
    public N endCondition() {
      return and();
    }
    
  
  }
  public class PrivateLoadBalancerNested<N> extends LoadBalancerStatusFluent<PrivateLoadBalancerNested<N>> implements Nested<N>{
    PrivateLoadBalancerNested(LoadBalancerStatus item) {
      this.builder = new LoadBalancerStatusBuilder(this, item);
    }
    LoadBalancerStatusBuilder builder;
    
    public N and() {
      return (N) IngressStatusFluent.this.withPrivateLoadBalancer(builder.build());
    }
    
    public N endPrivateLoadBalancer() {
      return and();
    }
    
  
  }
  public class PublicLoadBalancerNested<N> extends LoadBalancerStatusFluent<PublicLoadBalancerNested<N>> implements Nested<N>{
    PublicLoadBalancerNested(LoadBalancerStatus item) {
      this.builder = new LoadBalancerStatusBuilder(this, item);
    }
    LoadBalancerStatusBuilder builder;
    
    public N and() {
      return (N) IngressStatusFluent.this.withPublicLoadBalancer(builder.build());
    }
    
    public N endPublicLoadBalancer() {
      return and();
    }
    
  
  }

}
